@@ -1,9 +1,11 @@
 package App::JIRAPrint;
 # ABSTRACT: Print JIRA Tickets on Postit sheets
-$App::JIRAPrint::VERSION = '0.002';
+$App::JIRAPrint::VERSION = '0.003';
 use Moose;
 use Log::Any qw/$log/;
 
+use WWW::Shorten 'TinyURL', ':short';
+
 =head1 NAME
 
 App::JIRAPrint - Print JIRA Tickets on PostIt sheets
@@ -81,12 +83,12 @@ sub _build_jira{
 
 sub _build_fields{
     my ($self) = @_;
-    return $self->config()->{fields} // [ qw/key status summary assignee/ ];
+    return $self->config()->{fields} // [ qw/key status summary assignee issuetype/ ];
 }
 
 sub _build_maxissues{
     my ($self) = @_;
-    return $self->config()->{maxissues} // 50;
+    return $self->config()->{maxissues} // 100;
 }
 
 sub _build_url{
@@ -266,11 +268,11 @@ sub fetch_issues{
 
     $log->debug(&{
         (sub{
-             return "Issues ".( Data::Dumper->new([ $issues ])->Indent(0)->Terse(1)->Deparse(1)->Sortkeys(1)->Dump );
+             return "Issues ".( Data::Dumper->new([ $issues ])->Indent(1)->Terse(1)->Deparse(1)->Sortkeys(1)->Dump );
          })
     }() ) if $log->is_debug();
     foreach my $issue ( @{$issues->{issues}} ){
-        $issue->{url} = $self->url().'/browse/'.$issue->{key};
+        $issue->{url} = short_link($self->url().'/browse/'.$issue->{key});
     }
     return $issues;
 }
